#!/usr/bin/env python
# -*- coding: utf-8 -*-

from .GnuplotPy3 import GnuplotPy3

__all__ = [
            "GnuplotPy3",
          ]

version = "0.0.2"

print("""\

Welcome to GnuplotPy3_{VERSION}""".format( VERSION = version ) )
print()



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from subprocess import Popen, PIPE

class GnuplotPy3:
    def __init__(self):
        # 
        # Real time output requires `stdout = None` and `stderr = None`. 
        # `shell = True` might break the code on non-unix system.  But it 
        # provides flexibility to customize the command, e.g. with arguments.  
        # 
        self.gnuplot = Popen('gnuplot', shell = True, stdin=PIPE)


    def __del__(self):
        # Turn off stdin...
        self.gnuplot.stdin.close()

        # Wait until plotting is over...
        self.gnuplot.wait()

        # Terminate the subprcess...
        self.gnuplot.terminate()


    def __call__(self, s):
        # Keep reading the new Gnuplot command as a byte string...
        self.gnuplot.stdin.write( bytes( (s + '\n').encode() ) )

        # Flush it asap...
        self.gnuplot.stdin.flush()



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="GnuplotPy3",
    version="0.0.2",
    author="Cong Wang",
    author_email="wangimagine@gmail.com",
    description="A minimal Python wrapper for Gnuplot.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/carbonscott/GnuplotPy3",
    keywords = ['Gnuplot', 'wrapper'],
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)
